@@ -3,6 +3,7 @@ __license__ = "Apache-2.0"
 
 from . import request
 from .base import BaseClient, CallbackFnType, InputFnType
+from .websockets import WebSocketClientMixin
 from .helper import callback_exec
 from .request import GeneratorSourceType
 from ..enums import RequestType
@@ -10,8 +11,8 @@ from ..helper import run_async, deprecated_alias
 
 
 class Client(BaseClient):
-    """A simple Python client for connecting to the gateway.
-    It manges the asyncio eventloop internally, so all interfaces are synchronous from the outside.
+    """A simple Python client for connecting to the gRPC gateway.
+    It manages the asyncio eventloop internally, so all interfaces are synchronous from the outside.
     """
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
@@ -70,10 +71,10 @@ class Client(BaseClient):
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     def update(self, input_fn: InputFnType = None,
-              on_done: CallbackFnType = None,
-              on_error: CallbackFnType = None,
-              on_always: CallbackFnType = None,
-              **kwargs) -> None:
+               on_done: CallbackFnType = None,
+               on_error: CallbackFnType = None,
+               on_always: CallbackFnType = None,
+               **kwargs) -> None:
         """
 
         :param input_fn: the input function that generates the content
@@ -88,10 +89,10 @@ class Client(BaseClient):
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     def delete(self, input_fn: InputFnType = None,
-              on_done: CallbackFnType = None,
-              on_error: CallbackFnType = None,
-              on_always: CallbackFnType = None,
-              **kwargs) -> None:
+               on_done: CallbackFnType = None,
+               on_error: CallbackFnType = None,
+               on_always: CallbackFnType = None,
+               **kwargs) -> None:
         """
 
         :param input_fn: the input function that generates the content
@@ -102,4 +103,45 @@ class Client(BaseClient):
         :return:
         """
         self.mode = RequestType.DELETE
-        return run_async(self._get_results, input_fn, on_done, on_error, on_always, **kwargs)
\ No newline at end of file
+        return run_async(self._get_results, input_fn, on_done, on_error, on_always, **kwargs)
+
+
+class WebSocketClient(Client, WebSocketClientMixin):
+    """A Python Client to stream requests from a Flow with a RESTGateway
+    :class:`WebSocketClient` shares the same interface as :class:`Client` and provides methods like
+    :meth:`index`, "meth:`search`, :meth:`train`, :meth:`update` & :meth:`delete`.
+
+    It is used by default while running operations when we create a `Flow` with `rest_api=True`
+
+    .. highlight:: python
+    .. code-block:: python
+
+        from jina.flow import Flow
+        f = Flow(rest_api=True).add().add()
+
+        with f:
+            f.index(['abc'])
+
+
+    :class:`WebSocketClient` can also be used to run operations for a remote Flow
+
+    .. highlight:: python
+    .. code-block:: python
+
+        # A Flow running on remote
+        from jina.flow import Flow
+        f = Flow(rest_api=True, port_expose=34567).add().add()
+
+        with f:
+            f.block()
+
+        # Local WebSocketClient running index & search
+        from jina.clients import WebSocketClient
+
+        client = WebSocketClient(...)
+        client.index(...)
+        client.search(...)
+
+
+    :class:`WebSocketClient` internally handles an event loop to run operations asynchronously.
+    """
