@@ -209,6 +209,70 @@ class Flow(BaseFlow):
         """
         return self._get_client(**kwargs).index(input_fn, on_done, on_error, on_always, **kwargs)
 
+    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    def update(self, input_fn: InputFnType = None,
+              on_done: CallbackFnType = None,
+              on_error: CallbackFnType = None,
+              on_always: CallbackFnType = None,
+              **kwargs):
+        """Updates documents on the current flow
+        Example,
+        .. highlight:: python
+        .. code-block:: python
+            with f:
+                f.update(input_fn)
+                ...
+        This will call the pre-built reader to read files into an iterator of bytes and feed to the flow.
+        One may also build a reader/generator on your own.
+        Example,
+        .. highlight:: python
+        .. code-block:: python
+            def my_reader():
+                for _ in range(10):
+                    yield b'abcdfeg'  # each yield generates a document to update
+            with f.build(runtime='thread') as flow:
+                flow.update(bytes_gen=my_reader())
+        It will start a :py:class:`CLIClient` and call :py:func:`update`.
+        :param input_fn: An iterator of bytes. If not given, then you have to specify it in **kwargs**.
+        :param on_done: the function to be called when the :class:`Request` object is resolved.
+        :param on_error: the function to be called when the :class:`Request` object is rejected.
+        :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
+        :param kwargs: accepts all keyword arguments of `jina client` CLI
+        """
+        self._get_client(**kwargs).update(input_fn, on_done, on_error, on_always, **kwargs)
+
+    @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
+    def delete(self, input_fn: InputFnType = None,
+              on_done: CallbackFnType = None,
+              on_error: CallbackFnType = None,
+              on_always: CallbackFnType = None,
+              **kwargs):
+        """Do deletion on the current flow
+        Example,
+        .. highlight:: python
+        .. code-block:: python
+            with f:
+                f.delete(input_fn)
+                ...
+        This will call the pre-built reader to read files into an iterator of bytes and feed to the flow.
+        One may also build a reader/generator on your own.
+        Example,
+        .. highlight:: python
+        .. code-block:: python
+            def my_reader():
+                for _ in range(10):
+                    yield b'abcdfeg'  # each yield generates a document to delete
+            with f.build(runtime='thread') as flow:
+                flow.delete(bytes_gen=my_reader())
+        It will start a :py:class:`CLIClient` and call :py:func:`delete`.
+        :param input_fn: An iterator of bytes. If not given, then you have to specify it in **kwargs**.
+        :param on_done: the function to be called when the :class:`Request` object is resolved.
+        :param on_error: the function to be called when the :class:`Request` object is rejected.
+        :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
+        :param kwargs: accepts all keyword arguments of `jina client` CLI
+        """
+        self._get_client(**kwargs).delete(input_fn, on_done, on_error, on_always, **kwargs)
+
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     def search(self, input_fn: InputFnType = None,
                on_done: CallbackFnType = None,
